@@ -28,11 +28,12 @@
 
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <sys/errno.h>
+#include <cerrno>
 #include <fcntl.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <stdarg.h>
+#include <memory>
 #include <radosstriper/libradosstriper.hpp>
 #include <map>
 #include <stdexcept>
@@ -62,9 +63,21 @@ struct CephFile {
 struct CephFileRef : CephFile {
   int flags;
   mode_t mode;
-  unsigned long long offset;
+  uint64_t offset;
+  // This mutex protects against parallel updates of the stats.
+  XrdSysMutex statsMutex;
+  uint64_t maxOffsetWritten;
+  uint64_t bytesAsyncWritePending;
+  uint64_t bytesWritten;
   unsigned rdcount;
   unsigned wrcount;
+  unsigned asyncRdStartCount;
+  unsigned asyncRdCompletionCount;
+  unsigned asyncWrStartCount;
+  unsigned asyncWrCompletionCount;
+  ::timeval lastAsyncSubmission;
+  double longestAsyncWriteTime;
+  double longestCallbackInvocation;
 };
 
 /// small struct for directory listing
@@ -75,11 +88,13 @@ struct DirIterator {
 
 /// small struct for aio API callbacks
 struct AioArgs {
-  AioArgs(XrdSfsAio* a, AioCB *b, size_t n, ceph::bufferlist *_bl=0) :
-    aiop(a), callback(b), nbBytes(n), bl(_bl) {}
+  AioArgs(XrdSfsAio* a, AioCB *b, size_t n, int _fd, ceph::bufferlist *_bl=0) :
+    aiop(a), callback(b), nbBytes(n), fd(_fd), bl(_bl) { ::gettimeofday(&startTime, nullptr); }
   XrdSfsAio* aiop;
   AioCB *callback;
   size_t nbBytes;
+  int fd;
+  ::timeval startTime;
   ceph::bufferlist *bl;
 };
 
@@ -151,6 +166,10 @@ CephFileRef* getFileRef(int fd) {
   XrdSysMutexHelper lock(g_fd_mutex);
   std::map<unsigned int, CephFileRef>::iterator it = g_fds.find(fd);
   if (it != g_fds.end()) {
+    // We will release the lock upon exiting this function.
+    // The structure here is not protected from deletion, but we trust xrootd to
+    // ensure close (which does the deletion) will not be called before all previous
+    // calls are complete (including the async ones).
     return &(it->second);
   } else {
     return 0;
@@ -423,8 +442,19 @@ static CephFileRef getCephFileRef(const char *path, XrdOucEnv *env, int flags,
   fr.flags = flags;
   fr.mode = mode;
   fr.offset = 0;
+  fr.maxOffsetWritten = 0;
+  fr.bytesAsyncWritePending = 0;
+  fr.bytesWritten = 0;
   fr.rdcount = 0;
   fr.wrcount = 0;
+  fr.asyncRdStartCount = 0;
+  fr.asyncRdCompletionCount = 0;
+  fr.asyncWrStartCount = 0;
+  fr.asyncWrCompletionCount = 0;
+  fr.lastAsyncSubmission.tv_sec = 0;
+  fr.lastAsyncSubmission.tv_usec = 0;
+  fr.longestAsyncWriteTime = 0.0l;
+  fr.longestCallbackInvocation = 0.0l;
   return fr;
 }
 
@@ -543,9 +573,8 @@ int checkAndCreateStriper(unsigned int cephPoolIdx, std::string &userAtPool, con
       return 0;
     }
     IOCtxDict & ioDict = g_ioCtx[cephPoolIdx];
-    ioDict.insert(std::pair<std::string, librados::IoCtx*>(userAtPool, ioctx));
-    sDict.insert(std::pair<std::string, libradosstriper::RadosStriper*>
-                 (userAtPool, striper)).first;
+    ioDict.emplace(userAtPool, ioctx);
+    sDict.emplace(userAtPool, striper);
   }
   return 1;
 } 
@@ -603,48 +632,87 @@ void ceph_posix_set_logfunc(void (*logfunc) (char *, va_list argp)) {
 
 static int ceph_posix_internal_truncate(const CephFile &file, unsigned long long size);
 
-int ceph_posix_open(XrdOucEnv* env, const char *pathname, int flags, mode_t mode) {
+/**
+ * * brief ceph_posix_open function opens a file for read or write
+ * * details This function either:
+ * *    Opens a file for reading. If the file doesn't exist, this is an error.
+ * *    Opens a file for writing. If the file already exists, check whether overwrite has been requested. If overwrite
+ * *    hasn't been requested for an existing file, this is an error.
+ * * param env XrdOucEnv* Unused
+ * * param pathname const char* Specify the file to open.
+ * * param flags int Indicates whether reading or writing, and whether to overwrite an existing file.
+ * * param mode mode_t Unused
+ * * return int This is a file descriptor (non-negative) if the operation is successful,
+ * * or an error code (negative value) if the operation fails
+ * */
+
+int ceph_posix_open(XrdOucEnv* env, const char *pathname, int flags, mode_t mode){
+
   CephFileRef fr = getCephFileRef(pathname, env, flags, mode, 0);
-  int fd = insertFileRef(fr);
-  logwrapper((char*)"ceph_open: fd %d associated to %s", fd, pathname);
-  // in case of O_CREAT and O_EXCL, we should complain if the file exists
-  // in case of O_READ, the file has to exist
-  if (((flags & O_CREAT) && (flags & O_EXCL)) || ((flags&O_ACCMODE) == O_RDONLY)) {
-    libradosstriper::RadosStriper *striper = getRadosStriper(fr);
-    if (0 == striper) {
-      deleteFileRef(fd, fr);
-      return -EINVAL;
+
+  struct stat buf;
+  libradosstriper::RadosStriper *striper = getRadosStriper(fr); //Get a handle to the RADOS striper API
+ 
+  if (NULL == striper) {
+    logwrapper((char*)"Cannot create striper");  
+    return -EINVAL;
+  }
+ 
+  int rc = striper->stat(fr.name, (uint64_t*)&(buf.st_size), &(buf.st_atime)); //Get details about a file
+  
+ 
+  bool fileExists = (rc != -ENOENT); //Make clear what condition we are testing
+
+  if ((flags&O_ACCMODE) == O_RDONLY) {  // Access mode is READ
+
+    if (fileExists) {
+      int fd = insertFileRef(fr);
+      logwrapper((char*)"File descriptor %d associated to file %s opened in read mode", fd, pathname);
+      return fd;
+    } else {
+      return -ENOENT;
     }
-    struct stat buf;
-    int rc = striper->stat(fr.name, (uint64_t*)&(buf.st_size), &(buf.st_atime));
-    if ((flags&O_ACCMODE) == O_RDONLY) {
-      if (rc) {
-        deleteFileRef(fd, fr);
-        return rc;
+
+  } else {                              // Access mode is WRITE
+    if (fileExists) {
+      if (flags & O_TRUNC) {
+        int rc = ceph_posix_unlink(env, pathname);
+        if (rc < 0 && rc != -ENOENT) {
+          return rc;
+        }
+      } else {
+        return -EEXIST;
       }
-    } else if (rc != -ENOENT) {
-      deleteFileRef(fd, fr);
-      if (0 == rc) return -EEXIST;
-      return rc;
     }
+    // At this point, we know either the target file didn't exist, or the ceph_posix_unlink above removed it
+    int fd = insertFileRef(fr);
+    logwrapper((char*)"File descriptor %d associated to file %s opened in write mode", fd, pathname);
+    return fd;
+    
   }
-  // in case of O_TRUNC, we should truncate the file
-  if (flags & O_TRUNC) {
-    int rc = ceph_posix_internal_truncate(fr, 0);
-    // fail only if file exists and cannot be truncated
-    if (rc < 0 && rc != -ENOENT) {
-      deleteFileRef(fd, fr);
-      return rc;
-    }
-  }
-  return fd;
+    
 }
 
 int ceph_posix_close(int fd) {
   CephFileRef* fr = getFileRef(fd);
   if (fr) {
-    logwrapper((char*)"ceph_close: closed fd %d for file %s, read ops count %d, write ops count %d",
-               fd, fr->name.c_str(), fr->rdcount, fr->wrcount);
+    ::timeval now;
+    ::gettimeofday(&now, nullptr);
+    XrdSysMutexHelper lock(fr->statsMutex);
+    double lastAsyncAge = 0.0;
+    // Only compute an age if the starting point was set.
+    if (fr->lastAsyncSubmission.tv_sec && fr->lastAsyncSubmission.tv_usec) {
+      lastAsyncAge = 1.0 * (now.tv_sec - fr->lastAsyncSubmission.tv_sec) 
+              + 0.000001 * (now.tv_usec - fr->lastAsyncSubmission.tv_usec);
+    }
+    logwrapper((char*)"ceph_close: closed fd %d for file %s, read ops count %d, write ops count %d, "
+               "async write ops %d/%d, async pending write bytes %ld, "
+               "async read ops %d/%d, bytes written/max offset %ld/%ld, "
+               "longest async write %f, longest callback invocation %f, last async op age %f", 
+               fd, fr->name.c_str(), fr->rdcount, fr->wrcount, 
+               fr->asyncWrCompletionCount, fr->asyncWrStartCount, fr->bytesAsyncWritePending,
+               fr->asyncRdCompletionCount, fr->asyncRdStartCount, fr->bytesWritten,  fr->maxOffsetWritten,
+               fr->longestAsyncWriteTime, fr->longestCallbackInvocation, (lastAsyncAge));
     deleteFileRef(fd, *fr);
     return 0;
   } else {
@@ -702,7 +770,10 @@ ssize_t ceph_posix_write(int fd, const void *buf, size_t count) {
     int rc = striper->write(fr->name, bl, count, fr->offset);
     if (rc) return rc;
     fr->offset += count;
+    XrdSysMutexHelper lock(fr->statsMutex);
     fr->wrcount++;
+    fr->bytesWritten+=count;
+    if (fr->offset) fr->maxOffsetWritten = std::max(fr->offset - 1, fr->maxOffsetWritten);
     return count;
   } else {
     return -EBADF;
@@ -725,7 +796,10 @@ ssize_t ceph_posix_pwrite(int fd, const void *buf, size_t count, off64_t offset)
     bl.append((const char*)buf, count);
     int rc = striper->write(fr->name, bl, count, offset);
     if (rc) return rc;
+    XrdSysMutexHelper lock(fr->statsMutex);
     fr->wrcount++;
+    fr->bytesWritten+=count;
+    if (offset + count) fr->maxOffsetWritten = std::max(uint64_t(offset + count - 1), fr->maxOffsetWritten);
     return count;
   } else {
     return -EBADF;
@@ -735,7 +809,30 @@ ssize_t ceph_posix_pwrite(int fd, const void *buf, size_t count, off64_t offset)
 static void ceph_aio_write_complete(rados_completion_t c, void *arg) {
   AioArgs *awa = reinterpret_cast<AioArgs*>(arg);
   size_t rc = rados_aio_get_return_value(c);
+  // Compute statistics before reportng to xrootd, so that a close cannot happen
+  // in the meantime.
+  CephFileRef* fr = getFileRef(awa->fd);
+  if (fr) {
+    XrdSysMutexHelper lock(fr->statsMutex);
+    fr->asyncWrCompletionCount++;
+    fr->bytesAsyncWritePending -= awa->nbBytes;
+    fr->bytesWritten += awa->nbBytes;
+    if (awa->aiop->sfsAio.aio_nbytes)
+      fr->maxOffsetWritten = std::max(fr->maxOffsetWritten, uint64_t(awa->aiop->sfsAio.aio_offset + awa->aiop->sfsAio.aio_nbytes - 1));
+    ::timeval now;
+    ::gettimeofday(&now, nullptr);
+    double writeTime = 0.000001 * (now.tv_usec - awa->startTime.tv_usec) + 1.0 * (now.tv_sec - awa->startTime.tv_sec);
+    fr->longestAsyncWriteTime = std::max(fr->longestAsyncWriteTime, writeTime);
+  }
+  ::timeval before, after;
+  if (fr) ::gettimeofday(&before, nullptr);
   awa->callback(awa->aiop, rc == 0 ? awa->nbBytes : rc);
+  if (fr) {
+    ::gettimeofday(&after, nullptr);
+    double callbackInvocationTime = 0.000001 * (after.tv_usec - before.tv_usec) + 1.0 * (after.tv_sec - before.tv_sec);
+    XrdSysMutexHelper lock(fr->statsMutex);
+    fr->longestCallbackInvocation = std::max(fr->longestCallbackInvocation, callbackInvocationTime);
+  }
   delete(awa);
 }
 
@@ -767,12 +864,16 @@ ssize_t ceph_aio_write(int fd, XrdSfsAio *aiop, AioCB *cb) {
       return -EINVAL;
     }
     // prepare a ceph AioCompletion object and do async call
-    AioArgs *args = new AioArgs(aiop, cb, count);
+    AioArgs *args = new AioArgs(aiop, cb, count, fd);
     librados::AioCompletion *completion =
       cluster->aio_create_completion(args, ceph_aio_write_complete, NULL);
     // do the write
     int rc = striper->aio_write(fr->name, completion, bl, count, offset);
     completion->release();
+    XrdSysMutexHelper lock(fr->statsMutex);
+    fr->asyncWrStartCount++;
+    ::gettimeofday(&fr->lastAsyncSubmission, nullptr);
+    fr->bytesAsyncWritePending+=count;
     return rc;
   } else {
     return -EBADF;
@@ -794,7 +895,8 @@ ssize_t ceph_posix_read(int fd, void *buf, size_t count) {
     ceph::bufferlist bl;
     int rc = striper->read(fr->name, &bl, count, fr->offset);
     if (rc < 0) return rc;
-    bl.copy(0, rc, (char*)buf);
+    bl.begin().copy(rc, (char*)buf);
+    XrdSysMutexHelper lock(fr->statsMutex);
     fr->offset += rc;
     fr->rdcount++;
     return rc;
@@ -818,7 +920,8 @@ ssize_t ceph_posix_pread(int fd, void *buf, size_t count, off64_t offset) {
     ceph::bufferlist bl;
     int rc = striper->read(fr->name, &bl, count, offset);
     if (rc < 0) return rc;
-    bl.copy(0, rc, (char*)buf);
+    bl.begin().copy(rc, (char*)buf);
+    XrdSysMutexHelper lock(fr->statsMutex);
     fr->rdcount++;
     return rc;
   } else {
@@ -831,12 +934,19 @@ static void ceph_aio_read_complete(rados_completion_t c, void *arg) {
   size_t rc = rados_aio_get_return_value(c);
   if (awa->bl) {
     if (rc > 0) {
-      awa->bl->copy(0, rc, (char*)awa->aiop->sfsAio.aio_buf);
+      awa->bl->begin().copy(rc, (char*)awa->aiop->sfsAio.aio_buf);
     }
     delete awa->bl;
     awa->bl = 0;
   }
-  awa->callback(awa->aiop, rc == 0 ? awa->nbBytes : rc);
+  // Compute statistics before reportng to xrootd, so that a close cannot happen
+  // in the meantime.
+  CephFileRef* fr = getFileRef(awa->fd);
+  if (fr) {
+    XrdSysMutexHelper lock(fr->statsMutex);
+    fr->asyncRdCompletionCount++;
+  }
+  awa->callback(awa->aiop, rc );
   delete(awa);
 }
 
@@ -866,12 +976,14 @@ ssize_t ceph_aio_read(int fd, XrdSfsAio *aiop, AioCB *cb) {
       return -EINVAL;
     }
     // prepare a ceph AioCompletion object and do async call
-    AioArgs *args = new AioArgs(aiop, cb, count, bl);
+    AioArgs *args = new AioArgs(aiop, cb, count, fd, bl);
     librados::AioCompletion *completion =
       cluster->aio_create_completion(args, ceph_aio_read_complete, NULL);
     // do the read
     int rc = striper->aio_read(fr->name, completion, bl, count, offset);
     completion->release();
+    XrdSysMutexHelper lock(fr->statsMutex);
+    fr->asyncRdStartCount++;
     return rc;
   } else {
     return -EBADF;
@@ -935,6 +1047,7 @@ int ceph_posix_stat(XrdOucEnv* env, const char *pathname, struct stat *buf) {
 int ceph_posix_fsync(int fd) {
   CephFileRef* fr = getFileRef(fd);
   if (fr) {
+    // no locking of fr as it is not used.
     logwrapper((char*)"ceph_sync: fd %d", fd);
     return 0;
   } else {
@@ -968,7 +1081,7 @@ static ssize_t ceph_posix_internal_getxattr(const CephFile &file, const char* na
   int rc = striper->getxattr(file.name, name, bl);
   if (rc < 0) return rc;
   size_t returned_size = (size_t)rc<size?rc:size;
-  bl.copy(0, returned_size, (char*)value);
+  bl.begin().copy(returned_size, (char*)value);
   return returned_size;
 }
 
