@@ -75,7 +75,7 @@ namespace
         std::ostringstream data;
         data << ssp.st_dev << " " << ssp.st_size << " " << flags << " "
             << ssp.st_mtime;
-        log->Debug( FileMsg, data.str().c_str() );
+        log->Debug( FileMsg, "%s", data.str().c_str() );
 
         StatInfo *statInfo = new StatInfo();
         if( !statInfo->ParseServerResponse( data.str().c_str() ) )
@@ -308,7 +308,7 @@ namespace
         //----------------------------------------------------------------------
         if( !status->IsOK() )
         {
-          log->Dump( FileSystemMsg, "[0x%x@DeepLocate(%s)] Got error "
+          log->Dump( FileSystemMsg, "[%p@DeepLocate(%s)] Got error "
                      "response: %s", this, pPath.c_str(),
                      status->ToStr().c_str() );
 
@@ -317,7 +317,7 @@ namespace
           //--------------------------------------------------------------------
           if( pFirstTime )
           {
-            log->Debug( FileSystemMsg, "[0x%x@DeepLocate(%s)] Failed to get "
+            log->Debug( FileSystemMsg, "[%p@DeepLocate(%s)] Failed to get "
                         "the initial location list: %s", this, pPath.c_str(),
                         status->ToStr().c_str() );
             pHandler->HandleResponse( status, response );
@@ -334,7 +334,7 @@ namespace
           //--------------------------------------------------------------------
           if( !pOutstanding )
           {
-            log->Debug( FileSystemMsg, "[0x%x@DeepLocate(%s)] No outstanding "
+            log->Debug( FileSystemMsg, "[%p@DeepLocate(%s)] No outstanding "
                         "requests, give out what we've got", this,
                         pPath.c_str() );
             scopedLock.UnLock();
@@ -352,7 +352,7 @@ namespace
         response->Get( info );
         LocationInfo::Iterator it;
 
-        log->Dump( FileSystemMsg, "[0x%x@DeepLocate(%s)] Got %d locations",
+        log->Dump( FileSystemMsg, "[%p@DeepLocate(%s)] Got %d locations",
                    this, pPath.c_str(), info->GetSize() );
 
         for( it = info->Begin(); it != info->End(); ++it )
@@ -641,7 +641,7 @@ namespace
               XRootDStatus st = pCtx->fs->DirList( child, flags, handler, timeout );
               if( !st.IsOK() )
               {
-                log->Error( FileMsg, "Recursive directory list operation for %s failed: ",
+                log->Error( FileMsg, "Recursive directory list operation for %s failed: %s",
                             child.c_str(), st.ToString().c_str() );
                 pCtx->UpdateStatus( st );
                 continue;
@@ -944,8 +944,8 @@ namespace XrdCl
       Log *log = DefaultEnv::GetLog();
       XrdSysMutexHelper scopedLock( fs->pMutex );
 
-      log->Dump( FileSystemMsg, "[0x%x@%s] Sending %s", fs.get(),
-                 fs->pUrl->GetHostId().c_str(), msg->GetDescription().c_str() );
+      log->Dump( FileSystemMsg, "[%p@%s] Sending %s", fs.get(),
+                 fs->pUrl->GetHostId().c_str(), msg->GetObfuscatedDescription().c_str() );
 
       AssignLastURLHandler *lastUrlHandler = new AssignLastURLHandler( fs, handler );
       handler = lastUrlHandler;
@@ -980,7 +980,7 @@ namespace XrdCl
       if( pLoadBalancerLookupDone )
         return;
 
-      log->Dump( FileSystemMsg, "[0x%x@%s] Assigning %s as load balancer", this,
+      log->Dump( FileSystemMsg, "[%p@%s] Assigning %s as load balancer", this,
                  pUrl->GetHostId().c_str(), url.GetHostId().c_str() );
 
       pUrl.reset( new URL( url ) );
@@ -995,7 +995,7 @@ namespace XrdCl
       Log *log = DefaultEnv::GetLog();
       XrdSysMutexHelper scopedLock( pMutex );
 
-      log->Dump( FileSystemMsg, "[0x%x@%s] Assigning %s as last URL", this,
+      log->Dump( FileSystemMsg, "[%p@%s] Assigning %s as last URL", this,
                  pUrl->GetHostId().c_str(), url.GetHostId().c_str() );
 
       pLastUrl.reset( new URL( url ) );
@@ -1098,7 +1098,7 @@ namespace XrdCl
         if( !pPlugIn )
         {
           log->Error( FileMsg, "Plug-in factory failed to produce a plug-in "
-                      "for %s, continuing without one", urlStr.c_str() );
+                      "for %s, continuing without one", url.GetObfuscatedURL().c_str() );
         }
       }
     }
@@ -1737,37 +1737,49 @@ namespace XrdCl
     //--------------------------------------------------------------------------
     if( flags & DirListFlags::Locate )
     {
-      //------------------------------------------------------------------------
-      // Locate all the disk servers holding the directory
-      //------------------------------------------------------------------------
-      LocationInfo *locations;
-      std::string locatePath = "*"; locatePath += path;
-      XRootDStatus st = DeepLocate( locatePath,
-          OpenFlags::PrefName | OpenFlags::Compress | OpenFlags::IntentDirList, locations );
-
-      if( !st.IsOK() )
-        return st;
-
-      if( locations->GetSize() == 0 )
-      {
-        delete locations;
-        return XRootDStatus( stError, errNotFound );
-      }
-
-      // Check if destination is a data server
       bool isserver = false;
-      AnyObject obj;
-      st = DefaultEnv::GetPostMaster()->QueryTransport( *pImpl->fsdata->pUrl, XRootDQuery::ServerFlags, obj );
-      if( st.IsOK() )
+      //------------------------------------------------------------------------
+      // Check if destination is a data server
+      //------------------------------------------------------------------------
       {
-        int *ptr = 0;
-        obj.Get( ptr );
-        isserver = ( *ptr & kXR_isServer );
-        delete ptr;
+        AnyObject obj;
+        XRootDStatus st = DefaultEnv::GetPostMaster()->QueryTransport(
+            *pImpl->fsdata->pUrl, XRootDQuery::ServerFlags, obj);
+
+        if( st.IsOK() )
+        {
+          int *ptr = 0;
+          obj.Get( ptr );
+          isserver = ( *ptr & kXR_isServer );
+          delete ptr;
+        }
       }
 
-      if( !isserver )
-      {
+      if (isserver) {
+        // Just disable the locate flag if we are talking to a single server
+        flags &= ~DirListFlags::Locate;
+      } else {
+        //------------------------------------------------------------------------
+        // Locate all the disk servers holding the directory
+        //------------------------------------------------------------------------
+        LocationInfo *locations;
+        std::string locatePath = "*"; locatePath += path;
+
+        XRootDStatus st = DeepLocate(locatePath,
+                                     OpenFlags::PrefName |
+                                     OpenFlags::Compress |
+                                     OpenFlags::IntentDirList,
+                                     locations);
+
+        if( !st.IsOK() )
+          return st;
+
+        if( locations->GetSize() == 0 )
+        {
+          delete locations;
+          return XRootDStatus( stError, errNotFound );
+        }
+
         //------------------------------------------------------------------------
         // Ask each server for a directory list
         //------------------------------------------------------------------------
@@ -1811,6 +1823,7 @@ namespace XrdCl
           fs          = 0;
           currentResp = 0;
         }
+
         delete locations;
 
         if( flags & DirListFlags::Merge )
@@ -1824,8 +1837,6 @@ namespace XrdCl
         }
         return XRootDStatus();
       }
-      else
-        delete locations;
     }
 
     //--------------------------------------------------------------------------
