@@ -93,7 +93,7 @@ namespace XrdCl
     // if it is a compressed file use ZIP cache to read from the file
     if( cdfh->compressionMethod == Z_DEFLATED )
     {
-      log->Dump( ZipMsg, "[0x%x] Reading compressed data.", &me );
+      log->Dump( ZipMsg, "[%p] Reading compressed data.", &me );
       // check if respective ZIP cache exists
       bool empty = me.zipcache.find( fn ) == me.zipcache.end();
       // if the entry does not exist, it will be created using
@@ -156,8 +156,8 @@ namespace XrdCl
                        [relativeOffset, rdbuff, &cache, &me]( XRootDStatus &st, RSP &rsp )
                        {
                          Log *log = DefaultEnv::GetLog();
-                         log->Dump( ZipMsg, "[0x%x] Read %d bytes of remote data at offset %d.",
-                                            &me, rsp.GetLength(), rsp.GetOffset() );
+                         log->Dump( ZipMsg, "[%p] Read %u bytes of remote data at offset %llu.",
+                                            &me, rsp.GetLength(), (unsigned long long) rsp.GetOffset() );
                          cache.QueueRsp( st, relativeOffset, std::move( *rdbuff ) );
                        };
         Async( std::move( p ), timeout );
@@ -172,7 +172,7 @@ namespace XrdCl
       if( size )
       {
         memcpy( usrbuff, me.buffer.get() + offset, size );
-        log->Dump( ZipMsg, "[0x%x] Serving read from local cache.", &me );
+        log->Dump( ZipMsg, "[%p] Serving read from local cache.", &me );
       }
 
       if( usrHandler )
@@ -187,8 +187,8 @@ namespace XrdCl
     Pipeline p = XrdCl::RdWithRsp<RSP>( me.archive, offset, size, usrbuff ) >>
                    [=, &me]( XRootDStatus &st, RSP &r )
                    {
-                     log->Dump( ZipMsg, "[0x%x] Read %d bytes of remote data at "
-                                        "offset %d.", &me, r.GetLength(), r.GetOffset() );
+                     log->Dump( ZipMsg, "[%p] Read %u bytes of remote data at "
+                                        "offset %llu.", &me, r.GetLength(), (unsigned long long) r.GetOffset() );
                      if( usrHandler )
                      {
                        XRootDStatus *status = ZipArchive::make_status( st );
@@ -243,12 +243,12 @@ namespace XrdCl
                              {
                                archsize  = info.GetSize();
                                openstage = NotParsed;
-                               log->Debug( ZipMsg, "[0x%x] Opened (only) a ZIP archive (%s).",
+                               log->Debug( ZipMsg, "[%p] Opened (only) a ZIP archive (%s).",
                                            this, url.c_str() );
                              }
                              else
                              {
-                               log->Error( ZipMsg, "[0x%x] Failed to open-only a ZIP archive (%s): %s",
+                               log->Error( ZipMsg, "[%p] Failed to open-only a ZIP archive (%s): %s",
                                            this, url.c_str(), st.ToString().c_str() );
                              }
 
@@ -288,7 +288,7 @@ namespace XrdCl
                                  {
                                    cdexists = false;
                                    openstage = Done;
-                                   log->Dump( ZipMsg, "[0x%x] Opened a ZIP archive (file empty).", this );
+                                   log->Dump( ZipMsg, "[%p] Opened a ZIP archive (file empty).", this );
                                    Pipeline::Stop();
                                  }
                                  // prepare the arguments for the subsequent read
@@ -297,8 +297,8 @@ namespace XrdCl
                                  buffer.reset( new char[*rdsize] );
                                  rdbuff = buffer.get();
                                  openstage = HaveEocdBlk;
-                                 log->Dump( ZipMsg, "[0x%x] Opened a ZIP archive, reading "
-                                                    "Central Directory at offset: %d.", this, *rdoff );
+                                 log->Dump( ZipMsg, "[%p] Opened a ZIP archive, reading "
+                                                    "Central Directory at offset: %llu.", this, (unsigned long long) *rdoff );
                                }
                             // read the Central Directory (in several stages if necessary)
                           | XrdCl::Read( archive, rdoff, rdsize, rdbuff ) >>
@@ -324,15 +324,15 @@ namespace XrdCl
                                       }
                                       try{
                                       eocd.reset( new EOCD( eocdBlock, chunk.length - uint32_t(eocdBlock - buff) ) );
-                                      log->Dump( ZipMsg, "[0x%x] EOCD record parsed: %s", this,
+                                      log->Dump( ZipMsg, "[%p] EOCD record parsed: %s", this,
                                                          eocd->ToString().c_str() );
                                       if(eocd->cdOffset > archsize || eocd->cdOffset + eocd->cdSize > archsize)
-                                    	  throw bad_data();
+                                        throw bad_data();
                                       }
                                       catch(const bad_data &ex){
-                                    	  XRootDStatus error( stError, errDataError, 0,
-                                    	               "End-of-central-directory signature corrupted." );
-                                    	  Pipeline::Stop( error );
+                                        XRootDStatus error( stError, errDataError, 0,
+                                                            "End-of-central-directory signature corrupted." );
+                                        Pipeline::Stop( error );
                                       }
                                       // Do we have the whole archive?
                                       if( chunk.length == archsize )
@@ -371,15 +371,15 @@ namespace XrdCl
                                       buffer.reset( new char[*rdsize] );
                                       rdbuff    = buffer.get();
                                       openstage = HaveCdRecords;
-                                      log->Dump( ZipMsg, "[0x%x] Reading additional data at offset: %d.",
-                                                         this, *rdoff );
+                                      log->Dump( ZipMsg, "[%p] Reading additional data at offset: %llu.",
+                                                         this, (unsigned long long) *rdoff );
                                       Pipeline::Repeat(); break; // the break is really not needed ...
                                     }
 
                                     case HaveZip64EocdlBlk:
                                     {
                                       std::unique_ptr<ZIP64_EOCDL> eocdl( new ZIP64_EOCDL( buff ) );
-                                      log->Dump( ZipMsg, "[0x%x] EOCDL record parsed: %s",
+                                      log->Dump( ZipMsg, "[%p] EOCDL record parsed: %s",
                                                          this, eocdl->ToString().c_str() );
 
                                       if( chunk.offset > eocdl->zip64EocdOffset )
@@ -390,8 +390,8 @@ namespace XrdCl
                                         buffer.reset( new char[*rdsize] );
                                         rdbuff = buffer.get();
                                         openstage = HaveZip64EocdBlk;
-                                        log->Dump( ZipMsg, "[0x%x] Reading additional data at offset: %d.",
-                                                           this, *rdoff );
+                                        log->Dump( ZipMsg, "[%p] Reading additional data at offset: %llu.",
+                                                           this, (unsigned long long) *rdoff );
                                         Pipeline::Repeat();
                                       }
 
@@ -410,7 +410,7 @@ namespace XrdCl
                                         Pipeline::Stop( error );
                                       }
                                       zip64eocd.reset( new ZIP64_EOCD( buff ) );
-                                      log->Dump( ZipMsg, "[0x%x] ZIP64EOCD record parsed: %s",
+                                      log->Dump( ZipMsg, "[%p] ZIP64EOCD record parsed: %s",
                                                          this, zip64eocd->ToString().c_str() );
 
                                       // now we can read the CD records, adjust the read arguments
@@ -422,8 +422,8 @@ namespace XrdCl
                                       buffer.reset( new char[*rdsize] );
                                       rdbuff    = buffer.get();
                                       openstage = HaveCdRecords;
-                                      log->Dump( ZipMsg, "[0x%x] Reading additional data at offset: %d.",
-                                                         this, *rdoff );
+                                      log->Dump( ZipMsg, "[%p] Reading additional data at offset: %llu.",
+                                                         this, (unsigned long long) *rdoff );
                                       Pipeline::Repeat(); break; // the break is really not needed ...
                                     }
 
@@ -438,7 +438,7 @@ namespace XrdCl
                                           std::tie( cdvec, cdmap ) = CDFH::Parse( buff, zip64eocd->cdSize, zip64eocd->nbCdRec );
                                         else
                                           std::tie( cdvec, cdmap ) = CDFH::Parse( buff, eocd->cdSize, eocd->nbCdRec );
-                                        log->Dump( ZipMsg, "[0x%x] CD records parsed.", this );
+                                        log->Dump( ZipMsg, "[%p] CD records parsed.", this );
                                         uint64_t sumCompSize = 0;
                                         for (auto it = cdvec.begin(); it != cdvec.end(); it++)
                                         {
@@ -470,10 +470,10 @@ namespace XrdCl
                           | XrdCl::Final( [=]( const XRootDStatus &status )
                               { // finalize the pipeline by calling the user callback
                                 if( status.IsOK() )
-                                  log->Debug( ZipMsg, "[0x%x] Opened a ZIP archive (%s): %s",
+                                  log->Debug( ZipMsg, "[%p] Opened a ZIP archive (%s): %s",
                                               this, url.c_str(), status.ToString().c_str() );
                                 else
-                                  log->Error( ZipMsg, "[0x%x] Failed to open a ZIP archive (%s): %s",
+                                  log->Error( ZipMsg, "[%p] Failed to open a ZIP archive (%s): %s",
                                               this, url.c_str(), status.ToString().c_str() );
                                 if( handler )
                                   handler->HandleResponse( make_status( status ), nullptr );
@@ -504,11 +504,11 @@ namespace XrdCl
       {
         openfn = fn;
         lfh.reset( new LFH( fn, crc32, size, time( 0 ) ) );
-        log->Dump( ZipMsg, "[0x%x] File %s opened for append.",
+        log->Dump( ZipMsg, "[%p] File %s opened for append.",
                            this, fn.c_str() );
         return XRootDStatus();
       }
-      log->Dump( ZipMsg, "[0x%x] Open failed: %s not in the ZIP archive.",
+      log->Dump( ZipMsg, "[%p] Open failed: %s not in the ZIP archive.",
                          this, fn.c_str() );
       return XRootDStatus( stError, errNotFound );
     }
@@ -517,14 +517,14 @@ namespace XrdCl
     // a file with the same name
     if( flags & OpenFlags::New )
     {
-      log->Dump( ZipMsg, "[0x%x] Open failed: file exists %s, cannot append.",
+      log->Dump( ZipMsg, "[%p] Open failed: file exists %s, cannot append.",
                          this, fn.c_str() );
 
       return XRootDStatus( stError, errInvalidOp, EEXIST, "The file already exists in the ZIP archive." );
     }
 
     openfn = fn;
-    log->Dump( ZipMsg, "[0x%x] File %s opened for reading.",
+    log->Dump( ZipMsg, "[%p] File %s opened for reading.",
                        this, fn.c_str() );
     return XRootDStatus();
   }
@@ -650,10 +650,10 @@ namespace XrdCl
                  | XrdCl::Final( [=]( const XRootDStatus &st ) mutable
                      {
                        if( st.IsOK() )
-                         log->Dump( ZipMsg, "[0x%x] Successfully closed ZIP archive "
+                         log->Dump( ZipMsg, "[%p] Successfully closed ZIP archive "
                                             "(CD written).", this );
                        else
-                         log->Error( ZipMsg, "[0x%x] Failed to close ZIP archive: %s",
+                         log->Error( ZipMsg, "[%p] Failed to close ZIP archive: %s",
                                              this, st.ToString().c_str() );
                        wrtbufs.clear();
                        if( handler ) handler->HandleResponse( make_status( st ), nullptr );
@@ -672,13 +672,13 @@ namespace XrdCl
                      if( st.IsOK() )
                      {
                        Clear();
-                       log->Dump( ZipMsg, "[0x%x] Successfully closed "
+                       log->Dump( ZipMsg, "[%p] Successfully closed "
                                           "ZIP archive.", this );
                      }
                      else
                      {
                        openstage = Error;
-                       log->Error( ZipMsg, "[0x%x] Failed to close ZIP archive:"
+                       log->Error( ZipMsg, "[%p] Failed to close ZIP archive:"
                                            " %s", this, st.ToString().c_str() );
                      }
                      if( handler )
@@ -774,7 +774,7 @@ namespace XrdCl
       lfh->Serialize( *lfhbuf );
       iov[0].iov_base = lfhbuf->data();
       iov[0].iov_len  = lfhlen;
-      log->Dump( ZipMsg, "[0x%x] Will write LFH.", this );
+      log->Dump( ZipMsg, "[%p] Will write LFH.", this );
     }
     //-------------------------------------------------------------------------
     // If there is no LFH just make the first chunk empty.
@@ -886,12 +886,12 @@ namespace XrdCl
     // check if the file already exists in the archive
     if( itr != cdmap.end() )
     {
-      log->Dump( ZipMsg, "[0x%x] Open failed: file exists %s, cannot append.",
+      log->Dump( ZipMsg, "[%p] Open failed: file exists %s, cannot append.",
                          this, fn.c_str() );
       return XRootDStatus( stError, errInvalidOp );
     }
 
-    log->Dump( ZipMsg, "[0x%x] Appending file: %s.", this, fn.c_str() );
+    log->Dump( ZipMsg, "[%p] Appending file: %s.", this, fn.c_str() );
     //-------------------------------------------------------------------------
     // Create Local File Header record
     //-------------------------------------------------------------------------
