@@ -33,7 +33,7 @@
 /* (OpenSSL, Botan, ...)                                                      */
 /*                                                                            */
 /* ************************************************************************** */
-#include <time.h>
+#include <ctime>
 #include "XrdCrypto/XrdCryptoX509Crl.hh"
 
 //_____________________________________________________________________________
