@@ -28,14 +28,14 @@
 /* specific prior written permission of the institution or contributor.       */
 /******************************************************************************/
 
-#include <errno.h>
+#include <cerrno>
 #include <poll.h>
 #include <unistd.h>
 #include <sys/param.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#include <stdio.h>
+#include <cstdio>
 
 #include "XrdFrc/XrdFrcTrace.hh"
 #include "XrdFrm/XrdFrmCns.hh"
