@@ -36,6 +36,8 @@
 #include <unordered_set>
 #include <algorithm>
 
+#include <regex.h>
+
 #ifdef WIN32
 #include <direct.h>
 #include "XrdSys/XrdWin32.hh"
@@ -53,6 +55,7 @@
 #include "XrdOuc/XrdOucStream.hh"
 #include "XrdOuc/XrdOucString.hh"
 #include "XrdOuc/XrdOucUtils.hh"
+#include "XrdOuc/XrdOucPrivateUtils.hh"
 #include "XrdSys/XrdSysE2T.hh"
 #include "XrdSys/XrdSysError.hh"
 #include "XrdSys/XrdSysPlatform.hh"
@@ -113,7 +116,7 @@ int LookUp(idMap_t &idMap, unsigned int id, char *buff, int blen)
    return luRet;
 }
 }
-  
+
 /******************************************************************************/
 /*                               a r g L i s t                                */
 /******************************************************************************/
@@ -1145,9 +1148,11 @@ char *XrdOucUtils::subLogfn(XrdSysError &eDest, const char *inst, char *logfn)
 
 void XrdOucUtils::toLower(char *str)
 {
+   unsigned char* ustr = (unsigned char*)str;  // Avoid undefined behaviour
+
 // Change each character to lower case
 //
-   while(*str) {*str = tolower(*str); str++;}
+   while(*ustr) {*ustr = tolower(*ustr); ustr++;}
 }
   
 /******************************************************************************/
@@ -1412,46 +1417,63 @@ void XrdOucUtils::trim(std::string &str) {
         str.resize (str.size () - 1);
 }
 
-std::string XrdOucUtils::obfuscate(const std::string & input, const std::unordered_set<std::string>  & keysToObfuscate,const char keyValueDelimiter, const char listDelimiter) {
-    // String stream to build the result
-    std::ostringstream result;
+/**
+ * Returns a boolean indicating whether 'c' is a valid token character or not.
+ * See https://datatracker.ietf.org/doc/html/rfc6750#section-2.1 for details.
+ */
 
-    // Start processing the input string
-    std::istringstream inputStream(input);
-    std::string pair;
-    bool first = true;
+static bool is_token_character(int c)
+{
+  if (isalnum(c))
+    return true;
 
-    // Split input by listDelimiter
-    while (std::getline(inputStream, pair, listDelimiter)) {
-      if (!first) {
-        result << listDelimiter;
-      } else {
-        first = false;
-      }
+  static constexpr char token_chars[] = "-._~+/=:";
 
-      // Find the position of the keyValueDelimiter
-      size_t delimiterPos = pair.find(keyValueDelimiter);
-      if (delimiterPos != std::string::npos) {
-        std::string key = pair.substr(0, delimiterPos);
-        trim(key);
-        std::string lowerCasedKey = key;
-        std::transform(lowerCasedKey.begin(),lowerCasedKey.end(),lowerCasedKey.begin(),::tolower);
-        std::string value = pair.substr(delimiterPos + 1);
+  for (char ch : token_chars)
+    if (c == ch)
+      return true;
 
-        // Check if the key needs to be obfuscated
-        if (keysToObfuscate.find(lowerCasedKey) != keysToObfuscate.end()) {
-          result << key << keyValueDelimiter << OBFUSCATION_STR;
-        } else {
-          result << pair;
-        }
-      } else {
-        result << pair; // In case there's no delimiter in the pair, just append it
-      }
-    }
-
-    return result.str();
+  return false;
 }
 
+/**
+ * This function obfuscates away authz= cgi elements and/or HTTP authorization
+ * headers from URL or other log line strings which might contain them.
+ *
+ * @param input the string to obfuscate
+ * @return the string with token values obfuscated
+ */
+
+std::string obfuscateAuth(const std::string& input)
+{
+  static const regex_t auth_regex = []() {
+    constexpr char re[] =
+      "(authz=|(transferheader)?(www-|proxy-)?auth(orization|enticate)[[:space:]]*:[[:space:]]*)"
+      "(Bearer([[:space:]]|%20)?(token([[:space:]]|%20)?)?)?";
+
+    regex_t regex;
+
+    if (regcomp(&regex, re, REG_EXTENDED | REG_ICASE) != 0)
+      throw std::runtime_error("Failed to compile regular expression");
+
+    return regex;
+  }();
+
+  regmatch_t match;
+  size_t offset = 0;
+  std::string redacted;
+  const char *const text = input.c_str();
+
+  while (regexec(&auth_regex, text + offset, 1, &match, 0) == 0) {
+    redacted.append(text + offset, match.rm_eo).append("REDACTED");
+
+    offset += match.rm_eo;
+
+    while (offset < input.size() && is_token_character(input[offset]))
+      ++offset;
+  }
+
+  return redacted.append(text + offset);
+}
 
 #endif
-
