@@ -27,8 +27,8 @@
 /* specific prior written permission of the institution or contributor.       */
 /******************************************************************************/
 
-#include <stdio.h>
-#include <string.h>
+#include <cstdio>
+#include <cstring>
 #include <arpa/inet.h>
 #include <sys/types.h>
 
@@ -791,10 +791,10 @@ void XrdSsiFileReq::Recycle()
 {
 
 // If we have an oucbuffer then we need to recycle it, otherwise if we have
-// and sfs buffer, put it on the defered release queue.
+// and sfs buffer, put it on the deferred release queue.
 //
         if (oucBuff) {oucBuff->Recycle(); oucBuff = 0;}
-   else if (sfsBref) {XrdSfsXio::Reclaim(sfsBref);}
+   else if (sfsBref) {XrdSfsXio::Reclaim(sfsBref); sfsBref = 0;}
    reqSize = 0;
 
 // Add to queue unless we have too many of these. If we add it back to the
@@ -828,7 +828,7 @@ void XrdSsiFileReq::RelRequestBuffer()
 // Release buffers
 //
         if (oucBuff) {oucBuff->Recycle(); oucBuff = 0;}
-   else if (sfsBref) {XrdSfsXio::Reclaim(sfsBref);}
+   else if (sfsBref) {XrdSfsXio::Reclaim(sfsBref); sfsBref = 0;}
    reqSize = 0;
 }
 
